Function fasten_randomize::print_reads_from_stdin [−][src]
pub(crate) fn print_reads_from_stdin(lines_per_read: u32)Expand description
Read fastq from stdin, add the reads to a vector, then print them to stdout in random order